@@ -3,19 +3,19 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
+from __future__ import absolute_import, division, print_function
+
+
 __metaclass__ = type
 
+# These imports are needed so patching below works
+import ansible_collections.community.dns.plugins.module_utils.http  # noqa: F401, pylint: disable=unused-import
+from ansible_collections.community.dns.plugins.modules import hetzner_dns_record_set
 from ansible_collections.community.internal_test_tools.tests.unit.utils.fetch_url_module_framework import (
     BaseTestModule,
     FetchUrlCall,
 )
 
-from ansible_collections.community.dns.plugins.modules import hetzner_dns_record_set
-
-# These imports are needed so patching below works
-import ansible_collections.community.dns.plugins.module_utils.http  # noqa
-
 from .hetzner import (
     HETZNER_JSON_DEFAULT_ENTRIES,
     HETZNER_JSON_ZONE_GET_RESULT,
@@ -841,6 +841,7 @@ class TestHetznerDNSRecordJSON(BaseTestModule):
                     'ttl': 3600,
                     'zone_id': '42',
                 },
+                'error': {},
             }),
         ])
 
@@ -1247,6 +1248,79 @@ class TestHetznerDNSRecordJSON(BaseTestModule):
         }
 
     def test_change_modify_txt_quoted(self, mocker):
+        result = self.run_module_success(mocker, hetzner_dns_record_set, {
+            'hetzner_token': 'foo',
+            'state': 'present',
+            'zone_name': 'example.com',
+            'record': 'foo.example.com',
+            'type': 'TXT',
+            'ttl': None,
+            'value': [r'"b\195\164r \"with quotes\" (use \\ to escape)!"'],
+            'txt_transformation': 'quoted',
+            'txt_character_encoding': 'decimal',
+            '_ansible_diff': True,
+            '_ansible_remote_tmp': '/tmp/tmp',
+            '_ansible_keep_remote_files': True,
+        }, [
+            FetchUrlCall('GET', 200)
+            .expect_header('accept', 'application/json')
+            .expect_header('auth-api-token', 'foo')
+            .expect_url('https://dns.hetzner.com/api/v1/zones', without_query=True)
+            .expect_query_values('name', 'example.com')
+            .return_header('Content-Type', 'application/json')
+            .result_json(HETZNER_JSON_ZONE_LIST_RESULT),
+            FetchUrlCall('GET', 200)
+            .expect_header('accept', 'application/json')
+            .expect_header('auth-api-token', 'foo')
+            .expect_url('https://dns.hetzner.com/api/v1/records', without_query=True)
+            .expect_query_values('zone_id', '42')
+            .expect_query_values('page', '1')
+            .expect_query_values('per_page', '100')
+            .return_header('Content-Type', 'application/json')
+            .result_json(HETZNER_JSON_ZONE_RECORDS_GET_RESULT),
+            FetchUrlCall('PUT', 200)
+            .expect_header('accept', 'application/json')
+            .expect_header('auth-api-token', 'foo')
+            .expect_url('https://dns.hetzner.com/api/v1/records/201')
+            .expect_json_value_absent(['id'])
+            .expect_json_value(['type'], 'TXT')
+            .expect_json_value_absent(['ttl'])
+            .expect_json_value(['zone_id'], '42')
+            .expect_json_value(['name'], 'foo')
+            .expect_json_value(['value'], u'"bär \\"with quotes\\" (use \\\\ to escape)!"')
+            .return_header('Content-Type', 'application/json')
+            .result_json({
+                'record': {
+                    'id': '201',
+                    'type': 'TXT',
+                    'name': 'foo',
+                    'value': u'"bär \\"with quotes\\" (use \\\\ to escape)!"',
+                    'zone_id': '42',
+                },
+            }),
+        ])
+
+        assert result['changed'] is True
+        assert result['zone_id'] == '42'
+        assert 'diff' in result
+        assert 'before' in result['diff']
+        assert 'after' in result['diff']
+        assert result['diff']['before'] == {
+            'record': 'foo.example.com',
+            'prefix': 'foo',
+            'type': 'TXT',
+            'ttl': None,
+            'value': [r'"b\195\164r \"with quotes\" (use \\ to escape)"'],
+        }
+        assert result['diff']['after'] == {
+            'record': 'foo.example.com',
+            'prefix': 'foo',
+            'type': 'TXT',
+            'ttl': None,
+            'value': [r'"b\195\164r \"with quotes\" (use \\ to escape)!"'],
+        }
+
+    def test_change_modify_txt_quoted_octal(self, mocker):
         result = self.run_module_success(mocker, hetzner_dns_record_set, {
             'hetzner_token': 'foo',
             'state': 'present',
@@ -1256,6 +1330,7 @@ class TestHetznerDNSRecordJSON(BaseTestModule):
             'ttl': None,
             'value': [r'"b\303\244r \"with quotes\" (use \\ to escape)!"'],
             'txt_transformation': 'quoted',
+            'txt_character_encoding': 'octal',
             '_ansible_diff': True,
             '_ansible_remote_tmp': '/tmp/tmp',
             '_ansible_keep_remote_files': True,
