@@ -1,33 +1,36 @@
 # -*- coding: utf-8 -*-
-# (c) 2021, Felix Fontein <felix@fontein.de>
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# Copyright (c) 2021, Felix Fontein <felix@fontein.de>
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 # Make coding more python3-ish
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 
 import pytest
-
-from ansible_collections.community.internal_test_tools.tests.unit.compat.mock import patch
-
+from ansible_collections.community.dns.plugins.modules import wait_for_txt
+from ansible_collections.community.internal_test_tools.tests.unit.compat.mock import (
+    MagicMock,
+    patch,
+)
 from ansible_collections.community.internal_test_tools.tests.unit.plugins.modules.utils import (
-    set_module_args,
-    ModuleTestCase,
     AnsibleExitJson,
     AnsibleFailJson,
+    ModuleTestCase,
+    set_module_args,
 )
 
-from ansible_collections.community.dns.plugins.modules import wait_for_txt
-
 from ..module_utils.resolver_helper import (
-    mock_resolver,
-    mock_query_udp,
     create_mock_answer,
     create_mock_response,
+    mock_query_udp,
+    mock_resolver,
 )
 
+
 # We need dnspython
 dns = pytest.importorskip('dns')
 
@@ -48,10 +51,13 @@ def mock_monotonic(call_sequence):
 
 class TestWaitForTXT(ModuleTestCase):
     def test_single(self):
+        fake_query = MagicMock()
+        fake_query.question = 'Doctor Who?'
         resolver = mock_resolver(['1.1.1.1'], {
             ('1.1.1.1', ): [
                 {
                     'target': 'ns.example.com',
+                    'rdtype': dns.rdatatype.A,
                     'lifetime': 10,
                     'result': create_mock_answer(dns.rrset.from_rdata(
                         'ns.example.com',
@@ -59,8 +65,19 @@ class TestWaitForTXT(ModuleTestCase):
                         dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.A, '3.3.3.3'),
                     )),
                 },
+                {
+                    'target': 'ns.example.com',
+                    'rdtype': dns.rdatatype.AAAA,
+                    'lifetime': 10,
+                    'result': create_mock_answer(dns.rrset.from_rdata(
+                        'ns.example.com',
+                        300,
+                        dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.AAAA, '1:2::3'),
+                    )),
+                },
                 {
                     'target': 'ns.example.org',
+                    'rdtype': dns.rdatatype.A,
                     'lifetime': 10,
                     'result': create_mock_answer(dns.rrset.from_rdata(
                         'ns.example.org',
@@ -68,8 +85,14 @@ class TestWaitForTXT(ModuleTestCase):
                         dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.A, '4.4.4.4'),
                     )),
                 },
+                {
+                    'target': 'ns.example.org',
+                    'rdtype': dns.rdatatype.AAAA,
+                    'lifetime': 10,
+                    'raise': dns.resolver.NoAnswer(response=fake_query),
+                },
             ],
-            ('3.3.3.3', ): [
+            ('1:2::3', '3.3.3.3'): [
                 {
                     'target': dns.name.from_unicode(u'example.org'),
                     'rdtype': dns.rdatatype.TXT,
@@ -196,10 +219,13 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['check_count'] == 1
 
     def test_double(self):
+        fake_query = MagicMock()
+        fake_query.question = 'Doctor Who?'
         resolver = mock_resolver(['1.1.1.1'], {
             ('1.1.1.1', ): [
                 {
                     'target': 'ns.example.com',
+                    'rdtype': dns.rdatatype.A,
                     'lifetime': 10,
                     'result': create_mock_answer(dns.rrset.from_rdata(
                         'ns.example.com',
@@ -207,6 +233,12 @@ class TestWaitForTXT(ModuleTestCase):
                         dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.A, '3.3.3.3'),
                     )),
                 },
+                {
+                    'target': 'ns.example.com',
+                    'rdtype': dns.rdatatype.AAAA,
+                    'lifetime': 10,
+                    'raise': dns.resolver.NoAnswer(response=fake_query),
+                },
             ],
             ('3.3.3.3', ): [
                 {
@@ -351,10 +383,13 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][1]['check_count'] == 1
 
     def test_subset(self):
+        fake_query = MagicMock()
+        fake_query.question = 'Doctor Who?'
         resolver = mock_resolver(['1.1.1.1'], {
             ('1.1.1.1', ): [
                 {
                     'target': 'ns.example.com',
+                    'rdtype': dns.rdatatype.A,
                     'lifetime': 10,
                     'result': create_mock_answer(dns.rrset.from_rdata(
                         'ns.example.com',
@@ -362,6 +397,12 @@ class TestWaitForTXT(ModuleTestCase):
                         dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.A, '3.3.3.3'),
                     )),
                 },
+                {
+                    'target': 'ns.example.com',
+                    'rdtype': dns.rdatatype.AAAA,
+                    'lifetime': 10,
+                    'raise': dns.resolver.NoAnswer(response=fake_query),
+                },
             ],
             ('3.3.3.3', ): [
                 {
@@ -460,10 +501,13 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['check_count'] == 3
 
     def test_superset(self):
+        fake_query = MagicMock()
+        fake_query.question = 'Doctor Who?'
         resolver = mock_resolver(['1.1.1.1'], {
             ('1.1.1.1', ): [
                 {
                     'target': 'ns.example.com',
+                    'rdtype': dns.rdatatype.A,
                     'lifetime': 10,
                     'result': create_mock_answer(dns.rrset.from_rdata(
                         'ns.example.com',
@@ -471,6 +515,12 @@ class TestWaitForTXT(ModuleTestCase):
                         dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.A, '3.3.3.3'),
                     )),
                 },
+                {
+                    'target': 'ns.example.com',
+                    'rdtype': dns.rdatatype.AAAA,
+                    'lifetime': 10,
+                    'raise': dns.resolver.NoAnswer(response=fake_query),
+                },
             ],
             ('3.3.3.3', ): [
                 {
@@ -612,10 +662,13 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][1]['check_count'] == 1
 
     def test_superset_not_empty(self):
+        fake_query = MagicMock()
+        fake_query.question = 'Doctor Who?'
         resolver = mock_resolver(['1.1.1.1'], {
             ('1.1.1.1', ): [
                 {
                     'target': 'ns.example.com',
+                    'rdtype': dns.rdatatype.A,
                     'lifetime': 10,
                     'result': create_mock_answer(dns.rrset.from_rdata(
                         'ns.example.com',
@@ -623,6 +676,12 @@ class TestWaitForTXT(ModuleTestCase):
                         dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.A, '3.3.3.3'),
                     )),
                 },
+                {
+                    'target': 'ns.example.com',
+                    'rdtype': dns.rdatatype.AAAA,
+                    'lifetime': 10,
+                    'raise': dns.resolver.NoAnswer(response=fake_query),
+                },
             ],
             ('3.3.3.3', ): [
                 {
@@ -725,10 +784,13 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['check_count'] == 4
 
     def test_equals(self):
+        fake_query = MagicMock()
+        fake_query.question = 'Doctor Who?'
         resolver = mock_resolver(['1.1.1.1'], {
             ('1.1.1.1', ): [
                 {
                     'target': 'ns.example.com',
+                    'rdtype': dns.rdatatype.A,
                     'lifetime': 10,
                     'result': create_mock_answer(dns.rrset.from_rdata(
                         'ns.example.com',
@@ -736,6 +798,12 @@ class TestWaitForTXT(ModuleTestCase):
                         dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.A, '3.3.3.3'),
                     )),
                 },
+                {
+                    'target': 'ns.example.com',
+                    'rdtype': dns.rdatatype.AAAA,
+                    'lifetime': 10,
+                    'raise': dns.resolver.NoAnswer(response=fake_query),
+                },
             ],
             ('3.3.3.3', ): [
                 {
@@ -839,10 +907,13 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['check_count'] == 4
 
     def test_equals_ordered(self):
+        fake_query = MagicMock()
+        fake_query.question = 'Doctor Who?'
         resolver = mock_resolver(['1.1.1.1'], {
             ('1.1.1.1', ): [
                 {
                     'target': 'ns.example.com',
+                    'rdtype': dns.rdatatype.A,
                     'lifetime': 10,
                     'result': create_mock_answer(dns.rrset.from_rdata(
                         'ns.example.com',
@@ -850,6 +921,12 @@ class TestWaitForTXT(ModuleTestCase):
                         dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.A, '3.3.3.3'),
                     )),
                 },
+                {
+                    'target': 'ns.example.com',
+                    'rdtype': dns.rdatatype.AAAA,
+                    'lifetime': 10,
+                    'raise': dns.resolver.NoAnswer(response=fake_query),
+                },
             ],
             ('3.3.3.3', ): [
                 {
@@ -954,10 +1031,13 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['check_count'] == 4
 
     def test_timeout(self):
+        fake_query = MagicMock()
+        fake_query.question = 'Doctor Who?'
         resolver = mock_resolver(['1.1.1.1'], {
             ('1.1.1.1', ): [
                 {
                     'target': 'ns.example.com',
+                    'rdtype': dns.rdatatype.A,
                     'lifetime': 10,
                     'result': create_mock_answer(dns.rrset.from_rdata(
                         'ns.example.com',
@@ -965,6 +1045,12 @@ class TestWaitForTXT(ModuleTestCase):
                         dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.A, '3.3.3.3'),
                     )),
                 },
+                {
+                    'target': 'ns.example.com',
+                    'rdtype': dns.rdatatype.AAAA,
+                    'lifetime': 10,
+                    'raise': dns.resolver.NoAnswer(response=fake_query),
+                },
             ],
             ('3.3.3.3', ): [
                 {
@@ -1111,7 +1197,44 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][1]['check_count'] == 1
 
     def test_nxdomain(self):
-        resolver = mock_resolver(['1.1.1.1'], {})
+        resolver = mock_resolver(['1.1.1.1'], {
+            ('1.1.1.1', ): [
+                {
+                    'target': 'ns.example.com',
+                    'rdtype': dns.rdatatype.A,
+                    'lifetime': 10,
+                    'result': create_mock_answer(dns.rrset.from_rdata(
+                        'ns.example.com',
+                        300,
+                        dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.A, '3.3.3.3'),
+                    )),
+                },
+                {
+                    'target': 'ns.example.com',
+                    'rdtype': dns.rdatatype.AAAA,
+                    'lifetime': 10,
+                    'result': create_mock_answer(dns.rrset.from_rdata(
+                        'ns.example.com',
+                        300,
+                        dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.AAAA, '1:2::3'),
+                    )),
+                },
+            ],
+            ('1:2::3', '3.3.3.3'): [
+                {
+                    'target': dns.name.from_unicode(u'www.example.com'),
+                    'rdtype': dns.rdatatype.TXT,
+                    'lifetime': 10,
+                    'result': create_mock_answer(rcode=dns.rcode.NXDOMAIN),
+                },
+                {
+                    'target': dns.name.from_unicode(u'www.example.com'),
+                    'rdtype': dns.rdatatype.TXT,
+                    'lifetime': 10,
+                    'result': create_mock_answer(rcode=dns.rcode.NXDOMAIN),
+                },
+            ],
+        })
         udp_sequence = [
             {
                 'query_target': dns.name.from_unicode(u'com'),
@@ -1123,7 +1246,20 @@ class TestWaitForTXT(ModuleTestCase):
                 'result': create_mock_response(dns.rcode.NXDOMAIN),
             },
             {
-                'query_target': dns.name.from_unicode(u'com'),
+                'query_target': dns.name.from_unicode(u'example.com'),
+                'query_type': dns.rdatatype.NS,
+                'nameserver': '1.1.1.1',
+                'kwargs': {
+                    'timeout': 10,
+                },
+                'result': create_mock_response(dns.rcode.NOERROR, answer=[dns.rrset.from_rdata(
+                    'example.com',
+                    3600,
+                    dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.NS, 'ns.example.com'),
+                )]),
+            },
+            {
+                'query_target': dns.name.from_unicode(u'www.example.com'),
                 'query_type': dns.rdatatype.NS,
                 'nameserver': '1.1.1.1',
                 'kwargs': {
@@ -1153,12 +1289,14 @@ class TestWaitForTXT(ModuleTestCase):
                                 wait_for_txt.main()
 
         print(exc.value.args[0])
+        assert exc.value.args[0]['failed'] is True
         assert exc.value.args[0]['msg'] == 'Timeout (0 out of 1 check(s) passed).'
         assert exc.value.args[0]['completed'] == 0
         assert len(exc.value.args[0]['records']) == 1
         assert exc.value.args[0]['records'][0]['name'] == 'www.example.com'
         assert exc.value.args[0]['records'][0]['done'] is False
-        assert exc.value.args[0]['records'][0]['values'] == {}
+        assert len(exc.value.args[0]['records'][0]['values']) == 1
+        assert exc.value.args[0]['records'][0]['values']['ns.example.com'] == []
         assert exc.value.args[0]['records'][0]['check_count'] == 2
 
     def test_servfail(self):
@@ -1201,10 +1339,13 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['check_count'] == 0
 
     def test_cname_loop(self):
+        fake_query = MagicMock()
+        fake_query.question = 'Doctor Who?'
         resolver = mock_resolver(['1.1.1.1'], {
             ('1.1.1.1', ): [
                 {
                     'target': 'ns.example.com',
+                    'rdtype': dns.rdatatype.A,
                     'lifetime': 10,
                     'result': create_mock_answer(dns.rrset.from_rdata(
                         'ns.example.com',
@@ -1212,8 +1353,15 @@ class TestWaitForTXT(ModuleTestCase):
                         dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.A, '3.3.3.3'),
                     )),
                 },
+                {
+                    'target': 'ns.example.com',
+                    'rdtype': dns.rdatatype.AAAA,
+                    'lifetime': 10,
+                    'raise': dns.resolver.NoAnswer(response=fake_query),
+                },
                 {
                     'target': 'ns.example.org',
+                    'rdtype': dns.rdatatype.A,
                     'lifetime': 10,
                     'result': create_mock_answer(dns.rrset.from_rdata(
                         'ns.example.org',
@@ -1221,6 +1369,12 @@ class TestWaitForTXT(ModuleTestCase):
                         dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.A, '4.4.4.4'),
                     )),
                 },
+                {
+                    'target': 'ns.example.org',
+                    'rdtype': dns.rdatatype.AAAA,
+                    'lifetime': 10,
+                    'raise': dns.resolver.NoAnswer(response=fake_query),
+                },
             ],
         })
         udp_sequence = [
