@@ -1,10 +1,11 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-# Copyright: (c) 2018-2020 Andrew Klychkov (@Andersson007) <aaklychkov@mail.ru>
+# Copyright: (c) 2018-2020 Andrew Klychkov (@Andersson007) <andrew.a.klychkov@gmail.com>
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import absolute_import, division, print_function
+
 __metaclass__ = type
 
 DOCUMENTATION = r'''
@@ -30,19 +31,20 @@ options:
     version_added: '0.2.0'
   trust_input:
     description:
-    - If C(no), check whether a value of I(session_role) is potentially dangerous.
-    - It makes sense to use C(no) only when SQL injections via I(session_role) are possible.
+    - If C(false), check whether a value of I(session_role) is potentially dangerous.
+    - It makes sense to use C(false) only when SQL injections via I(session_role) are possible.
     type: bool
-    default: yes
+    default: true
     version_added: '0.2.0'
 seealso:
 - module: community.postgresql.postgresql_info
+attributes:
+  check_mode:
+    support: full
 author:
 - Andrew Klychkov (@Andersson007)
 extends_documentation_fragment:
 - community.postgresql.postgres
-notes:
-- Supports C(check_mode).
 '''
 
 EXAMPLES = r'''
@@ -64,52 +66,47 @@ EXAMPLES = r'''
   register: result
   # If you need to fail when the server is not available,
   # uncomment the following line:
-  #failed_when: not result.is_available
+  # failed_when: not result.is_available
 
 # You can use the registered result with another task
 - name: This task should be executed only if the server is available
   # ...
-  when: result.is_available == yes
+  when: result.is_available == true
 '''
 
 RETURN = r'''
 is_available:
   description: PostgreSQL server availability.
-  returned: always
+  returned: success
   type: bool
   sample: true
 server_version:
   description: PostgreSQL server version.
-  returned: always
+  returned: success
   type: dict
   sample: { major: 13, minor: 2, full: '13.2', raw: 'PostgreSQL 13.2 on x86_64-pc-linux-gnu' }
 conn_err_msg:
   description: Connection error message.
-  returned: always
+  returned: success
   type: str
   sample: ''
   version_added: 1.7.0
 '''
 
-try:
-    from psycopg2.extras import DictCursor
-except ImportError:
-    # psycopg2 is checked by connect_to_db()
-    # from ansible.module_utils.postgres
-    pass
+import re
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.postgresql.plugins.module_utils.database import (
-    check_input,
-)
+from ansible_collections.community.postgresql.plugins.module_utils.database import \
+    check_input
 from ansible_collections.community.postgresql.plugins.module_utils.postgres import (
     connect_to_db,
+    ensure_required_libs,
     exec_sql,
     get_conn_params,
+    pg_cursor_args,
     postgres_common_argument_spec,
 )
 
-
 # ===========================================
 # PostgreSQL module specific support methods.
 #
@@ -128,7 +125,7 @@ class PgPing(object):
 
     def get_pg_version(self):
         query = "SELECT version()"
-        raw = exec_sql(self, query, add_to_executed=False)[0][0]
+        raw = exec_sql(self, query, add_to_executed=False)[0]["version"]
 
         if not raw:
             return
@@ -136,13 +133,13 @@ class PgPing(object):
         self.is_available = True
 
         full = raw.split()[1]
-        tmp = full.split('.')
+        m = re.match(r"(\d+)\.(\d+)(?:\.(\d+))?", full)
 
-        major = int(tmp[0])
-        minor = int(tmp[1].rstrip(','))
+        major = int(m.group(1))
+        minor = int(m.group(2))
         patch = None
-        if len(tmp) >= 3:
-            patch = int(tmp[2].rstrip(','))
+        if m.group(3) is not None:
+            patch = int(m.group(3))
 
         self.version = dict(
             major=major,
@@ -186,20 +183,23 @@ def main():
         conn_err_msg='',
     )
 
+    # Ensure psycopg libraries are available before connecting to DB:
+    ensure_required_libs(module)
     conn_params = get_conn_params(module, module.params, warn_db_default=False)
     db_connection, err = connect_to_db(module, conn_params, fail_on_conn=False)
     if err:
         result['conn_err_msg'] = err
 
     if db_connection is not None:
-        cursor = db_connection.cursor(cursor_factory=DictCursor)
+        cursor = db_connection.cursor(**pg_cursor_args)
 
     # Do job:
     pg_ping = PgPing(module, cursor)
     if cursor:
         # If connection established:
         result["is_available"], result["server_version"] = pg_ping.do()
-        db_connection.rollback()
+        cursor.close()
+        db_connection.close()
 
     module.exit_json(**result)
 
