@@ -5,13 +5,13 @@
 
 set -e
 
-VERSION="10.2.0"
-MAJOR="10"
+VERSION="11.3.0"
+MAJOR="11"
 
 # For idempotency, remove build data or built output first
 rm -rf ansible-build-data built
 
-pip3 install --user --upgrade "antsibull==0.63.1"
+pip3 install --user --upgrade "antsibull-build==0.71.0"
 git clone https://github.com/ansible-community/ansible-build-data.git
 mkdir -p built collection-cache
 BUILD_DATA_DIR="ansible-build-data/${MAJOR}"
